# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/review/v1/review.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/review/v1/review.proto\x12\x30github.com.metaprov.modelaapi.services.review.v1\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a\x1cgoogle/api/annotations.proto\"\xc2\x01\n\x10GetReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12^\n\x06labels\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x11GetReviewResponse\x12L\n\x06review\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"c\n\x13\x43reateReviewRequest\x12L\n\x06review\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x16\n\x14\x43reateReviewResponse\"\x93\x01\n\x13UpdateReviewRequest\x12L\n\x06review\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateReviewResponse\"\xc8\x01\n\x13\x44\x65leteReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x61\n\x06labels\x18\x03 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x16\n\x14\x44\x65leteReviewResponse\"\xdd\x01\n\x11ListReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12_\n\x06labels\x18\x02 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x12ListReviewResponse\x12R\n\x08reviewes\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf5\x07\n\rReviewService\x12\xb9\x01\n\x0bListReviews\x12\x43.github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest\x1a\x44.github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/reviews/{namespace}\x12\xb5\x01\n\x0c\x43reateReview\x12\x45.github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest\x1a\x46.github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/reviews:\x01*\x12\xbc\x01\n\tGetReview\x12\x42.github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest\x1a\x43.github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/reviews/{namespace}/{name}\x12\xe8\x01\n\x0cUpdateReview\x12\x45.github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest\x1a\x46.github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/v1/reviews/{review.metadata.namespace}/{review.metadata.name}:\x01*\x12\xc5\x01\n\x0c\x44\x65leteReview\x12\x45.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest\x1a\x46.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/reviews/{namespace}/{name}B2Z0github.com/metaprov/modelaapi/services/review/v1b\x06proto3')



_GETREVIEWREQUEST = DESCRIPTOR.message_types_by_name['GetReviewRequest']
_GETREVIEWREQUEST_LABELSENTRY = _GETREVIEWREQUEST.nested_types_by_name['LabelsEntry']
_GETREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['GetReviewResponse']
_CREATEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['CreateReviewRequest']
_CREATEREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['CreateReviewResponse']
_UPDATEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['UpdateReviewRequest']
_UPDATEREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['UpdateReviewResponse']
_DELETEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['DeleteReviewRequest']
_DELETEREVIEWREQUEST_LABELSENTRY = _DELETEREVIEWREQUEST.nested_types_by_name['LabelsEntry']
_DELETEREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['DeleteReviewResponse']
_LISTREVIEWREQUEST = DESCRIPTOR.message_types_by_name['ListReviewRequest']
_LISTREVIEWREQUEST_LABELSENTRY = _LISTREVIEWREQUEST.nested_types_by_name['LabelsEntry']
_LISTREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['ListReviewResponse']
GetReviewRequest = _reflection.GeneratedProtocolMessageType('GetReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETREVIEWREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest)
  })
_sym_db.RegisterMessage(GetReviewRequest)
_sym_db.RegisterMessage(GetReviewRequest.LabelsEntry)

GetReviewResponse = _reflection.GeneratedProtocolMessageType('GetReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse)
  })
_sym_db.RegisterMessage(GetReviewResponse)

CreateReviewRequest = _reflection.GeneratedProtocolMessageType('CreateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest)
  })
_sym_db.RegisterMessage(CreateReviewRequest)

CreateReviewResponse = _reflection.GeneratedProtocolMessageType('CreateReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse)
  })
_sym_db.RegisterMessage(CreateReviewResponse)

UpdateReviewRequest = _reflection.GeneratedProtocolMessageType('UpdateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest)
  })
_sym_db.RegisterMessage(UpdateReviewRequest)

UpdateReviewResponse = _reflection.GeneratedProtocolMessageType('UpdateReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse)
  })
_sym_db.RegisterMessage(UpdateReviewResponse)

DeleteReviewRequest = _reflection.GeneratedProtocolMessageType('DeleteReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELETEREVIEWREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DELETEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest)
  })
_sym_db.RegisterMessage(DeleteReviewRequest)
_sym_db.RegisterMessage(DeleteReviewRequest.LabelsEntry)

DeleteReviewResponse = _reflection.GeneratedProtocolMessageType('DeleteReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse)
  })
_sym_db.RegisterMessage(DeleteReviewResponse)

ListReviewRequest = _reflection.GeneratedProtocolMessageType('ListReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTREVIEWREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest)
  })
_sym_db.RegisterMessage(ListReviewRequest)
_sym_db.RegisterMessage(ListReviewRequest.LabelsEntry)

ListReviewResponse = _reflection.GeneratedProtocolMessageType('ListReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse)
  })
_sym_db.RegisterMessage(ListReviewResponse)

_REVIEWSERVICE = DESCRIPTOR.services_by_name['ReviewService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/review/v1'
  _GETREVIEWREQUEST_LABELSENTRY._options = None
  _GETREVIEWREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DELETEREVIEWREQUEST_LABELSENTRY._options = None
  _DELETEREVIEWREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTREVIEWREQUEST_LABELSENTRY._options = None
  _LISTREVIEWREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _REVIEWSERVICE.methods_by_name['ListReviews']._options = None
  _REVIEWSERVICE.methods_by_name['ListReviews']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/reviews/{namespace}'
  _REVIEWSERVICE.methods_by_name['CreateReview']._options = None
  _REVIEWSERVICE.methods_by_name['CreateReview']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/reviews:\001*'
  _REVIEWSERVICE.methods_by_name['GetReview']._options = None
  _REVIEWSERVICE.methods_by_name['GetReview']._serialized_options = b'\202\323\344\223\002 \022\036/v1/reviews/{namespace}/{name}'
  _REVIEWSERVICE.methods_by_name['UpdateReview']._options = None
  _REVIEWSERVICE.methods_by_name['UpdateReview']._serialized_options = b'\202\323\344\223\002C\032>/v1/reviews/{review.metadata.namespace}/{review.metadata.name}:\001*'
  _REVIEWSERVICE.methods_by_name['DeleteReview']._options = None
  _REVIEWSERVICE.methods_by_name['DeleteReview']._serialized_options = b'\202\323\344\223\002 *\036/v1/reviews/{namespace}/{name}'
  _GETREVIEWREQUEST._serialized_start=279
  _GETREVIEWREQUEST._serialized_end=473
  _GETREVIEWREQUEST_LABELSENTRY._serialized_start=428
  _GETREVIEWREQUEST_LABELSENTRY._serialized_end=473
  _GETREVIEWRESPONSE._serialized_start=475
  _GETREVIEWRESPONSE._serialized_end=586
  _CREATEREVIEWREQUEST._serialized_start=588
  _CREATEREVIEWREQUEST._serialized_end=687
  _CREATEREVIEWRESPONSE._serialized_start=689
  _CREATEREVIEWRESPONSE._serialized_end=711
  _UPDATEREVIEWREQUEST._serialized_start=714
  _UPDATEREVIEWREQUEST._serialized_end=861
  _UPDATEREVIEWRESPONSE._serialized_start=863
  _UPDATEREVIEWRESPONSE._serialized_end=885
  _DELETEREVIEWREQUEST._serialized_start=888
  _DELETEREVIEWREQUEST._serialized_end=1088
  _DELETEREVIEWREQUEST_LABELSENTRY._serialized_start=428
  _DELETEREVIEWREQUEST_LABELSENTRY._serialized_end=473
  _DELETEREVIEWRESPONSE._serialized_start=1090
  _DELETEREVIEWRESPONSE._serialized_end=1112
  _LISTREVIEWREQUEST._serialized_start=1115
  _LISTREVIEWREQUEST._serialized_end=1336
  _LISTREVIEWREQUEST_LABELSENTRY._serialized_start=428
  _LISTREVIEWREQUEST_LABELSENTRY._serialized_end=473
  _LISTREVIEWRESPONSE._serialized_start=1339
  _LISTREVIEWRESPONSE._serialized_end=1468
  _REVIEWSERVICE._serialized_start=1471
  _REVIEWSERVICE._serialized_end=2484
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/tenant/v1/tenant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/tenant/v1/tenant.proto\x12\x30github.com.metaprov.modelaapi.services.tenant.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xfb\x01\n\x17ListTenantAlertsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x65\n\x06labels\x18\x02 \x03(\x0b\x32U.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantAlertsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x18ListTenantAlertsResponse\x12P\n\x06\x61lerts\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.AlertList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb8\x01\n\x12ListTenantsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x13ListTenantsResponse\x12R\n\x07tenants\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.TenantList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"d\n\x13\x43reateTenantRequest\x12M\n\x06tenant\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x16\n\x14\x43reateTenantResponse\"\x94\x01\n\x13UpdateTenantRequest\x12M\n\x06tenant\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateTenantResponse\"3\n\x10GetTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8c\x04\n\x11GetTenantResponse\x12M\n\x06tenant\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\x12L\n\x06\x61lerts\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12O\n\x08\x64\x61tasets\x18\x03 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12P\n\x07studies\x18\x04 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12O\n\x06models\x18\x05 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12X\n\npredictors\x18\x06 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12\x0c\n\x04yaml\x18\x07 \x01(\t\"6\n\x13\x44\x65leteTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteTenantResponse2\xa5\t\n\rTenantService\x12\xd1\x01\n\x10ListTenantAlerts\x12I.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantAlertsRequest\x1aJ.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantAlertsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/tenants/{namespace}:alerts\x12\xbb\x01\n\x0bListTenants\x12\x44.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest\x1a\x45.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/tenants/{namespace}\x12\xb5\x01\n\x0c\x43reateTenant\x12\x45.github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantRequest\x1a\x46.github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/tenants:\x01*\x12\xbc\x01\n\tGetTenant\x12\x42.github.com.metaprov.modelaapi.services.tenant.v1.GetTenantRequest\x1a\x43.github.com.metaprov.modelaapi.services.tenant.v1.GetTenantResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/tenants/{namespace}/{name}\x12\xe8\x01\n\x0cUpdateTenant\x12\x45.github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantRequest\x1a\x46.github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/v1/tenants/{tenant.metadata.namespace}/{tenant.metadata.name}:\x01*\x12\x9f\x01\n\x0c\x44\x65leteTenant\x12\x45.github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantRequest\x1a\x46.github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantResponse\"\x00\x42\x32Z0github.com/metaprov/modelaapi/services/tenant/v1b\x06proto3')



_LISTTENANTALERTSREQUEST = DESCRIPTOR.message_types_by_name['ListTenantAlertsRequest']
_LISTTENANTALERTSREQUEST_LABELSENTRY = _LISTTENANTALERTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTTENANTALERTSRESPONSE = DESCRIPTOR.message_types_by_name['ListTenantAlertsResponse']
_LISTTENANTSREQUEST = DESCRIPTOR.message_types_by_name['ListTenantsRequest']
_LISTTENANTSREQUEST_LABELSENTRY = _LISTTENANTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTTENANTSRESPONSE = DESCRIPTOR.message_types_by_name['ListTenantsResponse']
_CREATETENANTREQUEST = DESCRIPTOR.message_types_by_name['CreateTenantRequest']
_CREATETENANTRESPONSE = DESCRIPTOR.message_types_by_name['CreateTenantResponse']
_UPDATETENANTREQUEST = DESCRIPTOR.message_types_by_name['UpdateTenantRequest']
_UPDATETENANTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateTenantResponse']
_GETTENANTREQUEST = DESCRIPTOR.message_types_by_name['GetTenantRequest']
_GETTENANTRESPONSE = DESCRIPTOR.message_types_by_name['GetTenantResponse']
_DELETETENANTREQUEST = DESCRIPTOR.message_types_by_name['DeleteTenantRequest']
_DELETETENANTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteTenantResponse']
ListTenantAlertsRequest = _reflection.GeneratedProtocolMessageType('ListTenantAlertsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTTENANTALERTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantAlertsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTTENANTALERTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantAlertsRequest)
  })
_sym_db.RegisterMessage(ListTenantAlertsRequest)
_sym_db.RegisterMessage(ListTenantAlertsRequest.LabelsEntry)

ListTenantAlertsResponse = _reflection.GeneratedProtocolMessageType('ListTenantAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTALERTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantAlertsResponse)
  })
_sym_db.RegisterMessage(ListTenantAlertsResponse)

ListTenantsRequest = _reflection.GeneratedProtocolMessageType('ListTenantsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTTENANTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTTENANTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest)
  })
_sym_db.RegisterMessage(ListTenantsRequest)
_sym_db.RegisterMessage(ListTenantsRequest.LabelsEntry)

ListTenantsResponse = _reflection.GeneratedProtocolMessageType('ListTenantsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsResponse)
  })
_sym_db.RegisterMessage(ListTenantsResponse)

CreateTenantRequest = _reflection.GeneratedProtocolMessageType('CreateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantRequest)
  })
_sym_db.RegisterMessage(CreateTenantRequest)

CreateTenantResponse = _reflection.GeneratedProtocolMessageType('CreateTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantResponse)
  })
_sym_db.RegisterMessage(CreateTenantResponse)

UpdateTenantRequest = _reflection.GeneratedProtocolMessageType('UpdateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantRequest)
  })
_sym_db.RegisterMessage(UpdateTenantRequest)

UpdateTenantResponse = _reflection.GeneratedProtocolMessageType('UpdateTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENANTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantResponse)
  })
_sym_db.RegisterMessage(UpdateTenantResponse)

GetTenantRequest = _reflection.GeneratedProtocolMessageType('GetTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.GetTenantRequest)
  })
_sym_db.RegisterMessage(GetTenantRequest)

GetTenantResponse = _reflection.GeneratedProtocolMessageType('GetTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTENANTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.GetTenantResponse)
  })
_sym_db.RegisterMessage(GetTenantResponse)

DeleteTenantRequest = _reflection.GeneratedProtocolMessageType('DeleteTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantRequest)
  })
_sym_db.RegisterMessage(DeleteTenantRequest)

DeleteTenantResponse = _reflection.GeneratedProtocolMessageType('DeleteTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantResponse)
  })
_sym_db.RegisterMessage(DeleteTenantResponse)

_TENANTSERVICE = DESCRIPTOR.services_by_name['TenantService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/tenant/v1'
  _LISTTENANTALERTSREQUEST_LABELSENTRY._options = None
  _LISTTENANTALERTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTTENANTSREQUEST_LABELSENTRY._options = None
  _LISTTENANTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _TENANTSERVICE.methods_by_name['ListTenantAlerts']._options = None
  _TENANTSERVICE.methods_by_name['ListTenantAlerts']._serialized_options = b'\202\323\344\223\002 \022\036/v1/tenants/{namespace}:alerts'
  _TENANTSERVICE.methods_by_name['ListTenants']._options = None
  _TENANTSERVICE.methods_by_name['ListTenants']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/tenants/{namespace}'
  _TENANTSERVICE.methods_by_name['CreateTenant']._options = None
  _TENANTSERVICE.methods_by_name['CreateTenant']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/tenants:\001*'
  _TENANTSERVICE.methods_by_name['GetTenant']._options = None
  _TENANTSERVICE.methods_by_name['GetTenant']._serialized_options = b'\202\323\344\223\002 \022\036/v1/tenants/{namespace}/{name}'
  _TENANTSERVICE.methods_by_name['UpdateTenant']._options = None
  _TENANTSERVICE.methods_by_name['UpdateTenant']._serialized_options = b'\202\323\344\223\002C\032>/v1/tenants/{tenant.metadata.namespace}/{tenant.metadata.name}:\001*'
  _LISTTENANTALERTSREQUEST._serialized_start=470
  _LISTTENANTALERTSREQUEST._serialized_end=721
  _LISTTENANTALERTSREQUEST_LABELSENTRY._serialized_start=676
  _LISTTENANTALERTSREQUEST_LABELSENTRY._serialized_end=721
  _LISTTENANTALERTSRESPONSE._serialized_start=724
  _LISTTENANTALERTSRESPONSE._serialized_end=857
  _LISTTENANTSREQUEST._serialized_start=860
  _LISTTENANTSREQUEST._serialized_end=1044
  _LISTTENANTSREQUEST_LABELSENTRY._serialized_start=676
  _LISTTENANTSREQUEST_LABELSENTRY._serialized_end=721
  _LISTTENANTSRESPONSE._serialized_start=1047
  _LISTTENANTSRESPONSE._serialized_end=1177
  _CREATETENANTREQUEST._serialized_start=1179
  _CREATETENANTREQUEST._serialized_end=1279
  _CREATETENANTRESPONSE._serialized_start=1281
  _CREATETENANTRESPONSE._serialized_end=1303
  _UPDATETENANTREQUEST._serialized_start=1306
  _UPDATETENANTREQUEST._serialized_end=1454
  _UPDATETENANTRESPONSE._serialized_start=1456
  _UPDATETENANTRESPONSE._serialized_end=1478
  _GETTENANTREQUEST._serialized_start=1480
  _GETTENANTREQUEST._serialized_end=1531
  _GETTENANTRESPONSE._serialized_start=1534
  _GETTENANTRESPONSE._serialized_end=2058
  _DELETETENANTREQUEST._serialized_start=2060
  _DELETETENANTREQUEST._serialized_end=2114
  _DELETETENANTRESPONSE._serialized_start=2116
  _DELETETENANTRESPONSE._serialized_end=2138
  _TENANTSERVICE._serialized_start=2141
  _TENANTSERVICE._serialized_end=3330
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/virtualcluster/v1/virtualcluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMgithub.com/metaprov/modelaapi/services/virtualcluster/v1/virtualcluster.proto\x12\x38github.com.metaprov.modelaapi.services.virtualcluster.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xec\x01\n\x1aListVirtualClustersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x82\x01\n\x0fvirtualclusters\x18\x03 \x03(\x0b\x32i.github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.VirtualclustersEntry\x1a\x36\n\x14VirtualclustersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x1bListVirtualClustersResponse\x12\x62\n\x0fvirtualclusters\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualClusterList\"\x18\n\x16VirtualClusterResponse\"|\n\x1b\x43reateVirtualClusterRequest\x12]\n\x0evirtualcluster\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x1e\n\x1c\x43reateVirtualClusterResponse\"\xac\x01\n\x1bUpdateVirtualClusterRequest\x12]\n\x0evirtualcluster\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1e\n\x1cUpdateVirtualClusterResponse\";\n\x18GetVirtualClusterRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x88\x01\n\x19GetVirtualClusterResponse\x12]\n\x0evirtualcluster\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\x12\x0c\n\x04yaml\x18\x02 \x01(\t\">\n\x1b\x44\x65leteVirtualClusterRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteVirtualClusterResponse2\xff\t\n\x15VirtualClusterService\x12\xeb\x01\n\x13ListVirtualClusters\x12T.github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest\x1aU.github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/virtualclusters/{namespace}\x12\xe5\x01\n\x14\x43reateVirtualCluster\x12U.github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterRequest\x1aV.github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/virtualclusters:\x01*\x12\xec\x01\n\x11GetVirtualCluster\x12R.github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterRequest\x1aS.github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/virtualclusters/{namespace}/{name}\x12\xa8\x02\n\x14UpdateVirtualCluster\x12U.github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterRequest\x1aV.github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterResponse\"a\x82\xd3\xe4\x93\x02[\x1aV/v1/virtualclusters/{virtualcluster.metadata.namespace}/{virtualcluster.metadata.name}:\x01*\x12\xf5\x01\n\x14\x44\x65leteVirtualCluster\x12U.github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterRequest\x1aV.github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterResponse\".\x82\xd3\xe4\x93\x02(*&/v1/virtualclusters/{namespace}/{name}B:Z8github.com/metaprov/modelaapi/services/virtualcluster/v1b\x06proto3')



_LISTVIRTUALCLUSTERSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtualClustersRequest']
_LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERSENTRY = _LISTVIRTUALCLUSTERSREQUEST.nested_types_by_name['VirtualclustersEntry']
_LISTVIRTUALCLUSTERSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtualClustersResponse']
_VIRTUALCLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['VirtualClusterResponse']
_CREATEVIRTUALCLUSTERREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtualClusterRequest']
_CREATEVIRTUALCLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['CreateVirtualClusterResponse']
_UPDATEVIRTUALCLUSTERREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtualClusterRequest']
_UPDATEVIRTUALCLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['UpdateVirtualClusterResponse']
_GETVIRTUALCLUSTERREQUEST = DESCRIPTOR.message_types_by_name['GetVirtualClusterRequest']
_GETVIRTUALCLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['GetVirtualClusterResponse']
_DELETEVIRTUALCLUSTERREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtualClusterRequest']
_DELETEVIRTUALCLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteVirtualClusterResponse']
ListVirtualClustersRequest = _reflection.GeneratedProtocolMessageType('ListVirtualClustersRequest', (_message.Message,), {

  'VirtualclustersEntry' : _reflection.GeneratedProtocolMessageType('VirtualclustersEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.VirtualclustersEntry)
    })
  ,
  'DESCRIPTOR' : _LISTVIRTUALCLUSTERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest)
  })
_sym_db.RegisterMessage(ListVirtualClustersRequest)
_sym_db.RegisterMessage(ListVirtualClustersRequest.VirtualclustersEntry)

ListVirtualClustersResponse = _reflection.GeneratedProtocolMessageType('ListVirtualClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALCLUSTERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersResponse)
  })
_sym_db.RegisterMessage(ListVirtualClustersResponse)

VirtualClusterResponse = _reflection.GeneratedProtocolMessageType('VirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterResponse)
  })
_sym_db.RegisterMessage(VirtualClusterResponse)

CreateVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterRequest)
  })
_sym_db.RegisterMessage(CreateVirtualClusterRequest)

CreateVirtualClusterResponse = _reflection.GeneratedProtocolMessageType('CreateVirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterResponse)
  })
_sym_db.RegisterMessage(CreateVirtualClusterResponse)

UpdateVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualClusterRequest)

UpdateVirtualClusterResponse = _reflection.GeneratedProtocolMessageType('UpdateVirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterResponse)
  })
_sym_db.RegisterMessage(UpdateVirtualClusterResponse)

GetVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('GetVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterRequest)
  })
_sym_db.RegisterMessage(GetVirtualClusterRequest)

GetVirtualClusterResponse = _reflection.GeneratedProtocolMessageType('GetVirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterResponse)
  })
_sym_db.RegisterMessage(GetVirtualClusterResponse)

DeleteVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualClusterRequest)

DeleteVirtualClusterResponse = _reflection.GeneratedProtocolMessageType('DeleteVirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterResponse)
  })
_sym_db.RegisterMessage(DeleteVirtualClusterResponse)

_VIRTUALCLUSTERSERVICE = DESCRIPTOR.services_by_name['VirtualClusterService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/metaprov/modelaapi/services/virtualcluster/v1'
  _LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERSENTRY._options = None
  _LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERSENTRY._serialized_options = b'8\001'
  _VIRTUALCLUSTERSERVICE.methods_by_name['ListVirtualClusters']._options = None
  _VIRTUALCLUSTERSERVICE.methods_by_name['ListVirtualClusters']._serialized_options = b'\202\323\344\223\002!\022\037/v1/virtualclusters/{namespace}'
  _VIRTUALCLUSTERSERVICE.methods_by_name['CreateVirtualCluster']._options = None
  _VIRTUALCLUSTERSERVICE.methods_by_name['CreateVirtualCluster']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/virtualclusters:\001*'
  _VIRTUALCLUSTERSERVICE.methods_by_name['GetVirtualCluster']._options = None
  _VIRTUALCLUSTERSERVICE.methods_by_name['GetVirtualCluster']._serialized_options = b'\202\323\344\223\002(\022&/v1/virtualclusters/{namespace}/{name}'
  _VIRTUALCLUSTERSERVICE.methods_by_name['UpdateVirtualCluster']._options = None
  _VIRTUALCLUSTERSERVICE.methods_by_name['UpdateVirtualCluster']._serialized_options = b'\202\323\344\223\002[\032V/v1/virtualclusters/{virtualcluster.metadata.namespace}/{virtualcluster.metadata.name}:\001*'
  _VIRTUALCLUSTERSERVICE.methods_by_name['DeleteVirtualCluster']._options = None
  _VIRTUALCLUSTERSERVICE.methods_by_name['DeleteVirtualCluster']._serialized_options = b'\202\323\344\223\002(*&/v1/virtualclusters/{namespace}/{name}'
  _LISTVIRTUALCLUSTERSREQUEST._serialized_start=338
  _LISTVIRTUALCLUSTERSREQUEST._serialized_end=574
  _LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERSENTRY._serialized_start=520
  _LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERSENTRY._serialized_end=574
  _LISTVIRTUALCLUSTERSRESPONSE._serialized_start=577
  _LISTVIRTUALCLUSTERSRESPONSE._serialized_end=706
  _VIRTUALCLUSTERRESPONSE._serialized_start=708
  _VIRTUALCLUSTERRESPONSE._serialized_end=732
  _CREATEVIRTUALCLUSTERREQUEST._serialized_start=734
  _CREATEVIRTUALCLUSTERREQUEST._serialized_end=858
  _CREATEVIRTUALCLUSTERRESPONSE._serialized_start=860
  _CREATEVIRTUALCLUSTERRESPONSE._serialized_end=890
  _UPDATEVIRTUALCLUSTERREQUEST._serialized_start=893
  _UPDATEVIRTUALCLUSTERREQUEST._serialized_end=1065
  _UPDATEVIRTUALCLUSTERRESPONSE._serialized_start=1067
  _UPDATEVIRTUALCLUSTERRESPONSE._serialized_end=1097
  _GETVIRTUALCLUSTERREQUEST._serialized_start=1099
  _GETVIRTUALCLUSTERREQUEST._serialized_end=1158
  _GETVIRTUALCLUSTERRESPONSE._serialized_start=1161
  _GETVIRTUALCLUSTERRESPONSE._serialized_end=1297
  _DELETEVIRTUALCLUSTERREQUEST._serialized_start=1299
  _DELETEVIRTUALCLUSTERREQUEST._serialized_end=1361
  _DELETEVIRTUALCLUSTERRESPONSE._serialized_start=1363
  _DELETEVIRTUALCLUSTERRESPONSE._serialized_end=1393
  _VIRTUALCLUSTERSERVICE._serialized_start=1396
  _VIRTUALCLUSTERSERVICE._serialized_end=2675
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/common/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/common/v1/common.proto\x12\x30github.com.metaprov.modelaapi.services.common.v1\"\xd8\x02\n\x0e\x44\x61tasetProfile\x12\x0c\n\x04\x63ols\x18\x01 \x01(\x05\x12\x0c\n\x04rows\x18\x02 \x01(\x05\x12\x10\n\x08\x66ilesize\x18\x03 \x01(\x05\x12\x11\n\timbalance\x18\x04 \x01(\x08\x12\x45\n\x05plots\x18\x05 \x03(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\x12P\n\x07\x63olumns\x18\x06 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.ColumnProfile\x12J\n\x05table\x18\x07 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\x12\x0c\n\x04hash\x18\x08 \x01(\t\x12\x12\n\nanomalyURI\x18\t \x01(\t\"\xce\x04\n\x0cModelProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x05plots\x18\x02 \x03(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\x12\x62\n\nimportance\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.common.v1.ModelProfile.ImportanceEntry\x12J\n\x06rocauc\x18\x04 \x01(\x0b\x32:.github.com.metaprov.modelaapi.services.common.v1.ROCCurve\x12R\n\x02pr\x18\x05 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.services.common.v1.PrecisionRecallCurve\x12T\n\x10multiclassRocAuc\x18\x06 \x03(\x0b\x32:.github.com.metaprov.modelaapi.services.common.v1.ROCCurve\x12\\\n\x0cmulticlassPR\x18\x07 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.services.common.v1.PrecisionRecallCurve\x1a\x31\n\x0fImportanceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\\\n\x08ROCCurve\x12\x11\n\tclassname\x18\x01 \x01(\t\x12\x0f\n\x07\x63lassid\x18\x02 \x01(\x05\x12\x0b\n\x03\x66pr\x18\x03 \x03(\x01\x12\x0b\n\x03tpr\x18\x04 \x03(\x01\x12\x12\n\nthresholds\x18\x05 \x03(\x01\"q\n\x14PrecisionRecallCurve\x12\x11\n\tclassname\x18\x01 \x01(\t\x12\x0f\n\x07\x63lassid\x18\x02 \x01(\x05\x12\x11\n\tprecision\x18\x03 \x03(\x01\x12\x0e\n\x06recall\x18\x04 \x03(\x01\x12\x12\n\nthresholds\x18\x05 \x03(\x01\"f\n\x0f\x46orecastProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x05plots\x18\x02 \x03(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\"\xe8\x01\n\x0cStudyProfile\x12\x45\n\x05plots\x18\x01 \x03(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\x12N\n\x06models\x18\x02 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.ModelProfile\x12\x14\n\x0ctrainingHash\x18\x03 \x01(\t\x12\x13\n\x0btestingHash\x18\x04 \x01(\t\x12\x16\n\x0evalidationHash\x18\x05 \x01(\t\"L\n\x04Plot\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03img\x18\x03 \x01(\x0c\x12\r\n\x05\x66name\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\xd3\x07\n\rColumnProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07missing\x18\x04 \x01(\x05\x12\x16\n\x0epercentMissing\x18\x05 \x01(\x02\x12\x10\n\x08\x64istinct\x18\x06 \x01(\x05\x12\x0c\n\x04mean\x18\x07 \x01(\x01\x12\x0c\n\x04mode\x18\x08 \x01(\t\x12\x0e\n\x06stddev\x18\t \x01(\x01\x12\x10\n\x08variance\x18\n \x01(\x01\x12\x0b\n\x03min\x18\x0b \x01(\x01\x12\x0b\n\x03max\x18\x0c \x01(\x01\x12\x10\n\x08kurtosis\x18\r \x01(\x01\x12\x10\n\x08skewness\x18\x0e \x01(\x01\x12\x0b\n\x03sum\x18\x0f \x01(\x01\x12\x0b\n\x03mad\x18\x10 \x01(\x01\x12\r\n\x05zeros\x18\x11 \x01(\x01\x12\x0b\n\x03p25\x18\x12 \x01(\x01\x12\x0b\n\x03p50\x18\x13 \x01(\x01\x12\x0b\n\x03p75\x18\x14 \x01(\x01\x12\x0c\n\x04p100\x18\x15 \x01(\x01\x12\x0b\n\x03iqr\x18\x16 \x01(\x01\x12\n\n\x02\x63v\x18\x17 \x01(\x01\x12\x0b\n\x03top\x18\x18 \x01(\x05\x12\x0c\n\x04\x66req\x18\x19 \x01(\x05\x12\x0e\n\x06ignore\x18\x1a \x01(\x08\x12\x0e\n\x06target\x18\x1b \x01(\x08\x12N\n\thistogram\x18\x1c \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.Histogram\x12\x0f\n\x07invalid\x18\x1d \x01(\x05\x12\x12\n\nimportance\x18\x1e \x01(\x01\x12\x10\n\x08nullable\x18\x1f \x01(\x08\x12\x17\n\x0fhighCardinality\x18  \x01(\x08\x12!\n\x19highCorrWithOtherFeatures\x18! \x01(\x08\x12\x19\n\x11lowCorrWithTarget\x18\" \x01(\x08\x12\x16\n\x0ehighMissingPct\x18# \x01(\x08\x12\x0e\n\x06skewed\x18$ \x01(\x08\x12\n\n\x02id\x18% \x01(\x08\x12\x10\n\x08\x63onstant\x18& \x01(\x08\x12\x11\n\tduplicate\x18\' \x01(\x08\x12\x10\n\x08reserved\x18( \x01(\x08\x12\x15\n\routliersUpper\x18) \x01(\x05\x12\x15\n\routliersLower\x18* \x01(\x05\x12\x17\n\x0foutliersPercent\x18+ \x01(\x02\x12\x14\n\x0c\x63ompleteness\x18, \x01(\x01\x12\x1a\n\x12\x64istinctValueCount\x18- \x01(\x01\x12\x1b\n\x13mostFreqValuesRatio\x18. \x01(\x01\x12\x1a\n\x12indexOfPeculiarity\x18/ \x01(\x01\x12\x0e\n\x06values\x18\x30 \x03(\t\x12\x14\n\x0c\x63orrToTarget\x18\x31 \x01(\x01\x12\r\n\x05index\x18\x32 \x01(\x05\"=\n\tHistogram\x12\x0e\n\x06values\x18\x01 \x03(\x01\x12\x0c\n\x04\x62ins\x18\x02 \x03(\x01\x12\x12\n\ncategories\x18\x03 \x03(\t\"\xf6\x02\n\rNamespaceInfo\x12[\n\x04type\x18\x01 \x01(\x0e\x32M.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.NamespaceType\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x10\n\x08\x61\x63\x63ounts\x18\x03 \x01(\x05\x12\x0f\n\x07\x62uckets\x18\x04 \x01(\x05\x12\x0c\n\x04labs\x18\x05 \x01(\x05\x12\x14\n\x0cservingsites\x18\x06 \x01(\x05\x12\x10\n\x08\x64\x61tasets\x18\x07 \x01(\x05\x12\x13\n\x0b\x64\x61tasources\x18\x08 \x01(\x05\x12\x0f\n\x07studies\x18\t \x01(\x05\x12\x0e\n\x06models\x18\n \x01(\x05\"k\n\rNamespaceType\x12\n\n\x06TENANT\x10\x00\x12\x0f\n\x0b\x44\x41TAPRODUCT\x10\x01\x12\x07\n\x03LAB\x10\x02\x12\x0f\n\x0bSERVINGSITE\x10\x03\x12\x10\n\x0cMODELASYSTEM\x10\x04\x12\x11\n\rMODELACATALOG\x10\x05\"\xba\x01\n\tTableView\x12\x0c\n\x04\x63ols\x18\x01 \x03(\t\x12L\n\x04rows\x18\x02 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.TableViewRow\x12Q\n\x08profiles\x18\x03 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.ColumnProfile\"\x1e\n\x0cTableViewRow\x12\x0e\n\x06values\x18\x01 \x03(\tB2Z0github.com/metaprov/modelaapi/services/common/v1b\x06proto3')



_DATASETPROFILE = DESCRIPTOR.message_types_by_name['DatasetProfile']
_MODELPROFILE = DESCRIPTOR.message_types_by_name['ModelProfile']
_MODELPROFILE_IMPORTANCEENTRY = _MODELPROFILE.nested_types_by_name['ImportanceEntry']
_ROCCURVE = DESCRIPTOR.message_types_by_name['ROCCurve']
_PRECISIONRECALLCURVE = DESCRIPTOR.message_types_by_name['PrecisionRecallCurve']
_FORECASTPROFILE = DESCRIPTOR.message_types_by_name['ForecastProfile']
_STUDYPROFILE = DESCRIPTOR.message_types_by_name['StudyProfile']
_PLOT = DESCRIPTOR.message_types_by_name['Plot']
_COLUMNPROFILE = DESCRIPTOR.message_types_by_name['ColumnProfile']
_HISTOGRAM = DESCRIPTOR.message_types_by_name['Histogram']
_NAMESPACEINFO = DESCRIPTOR.message_types_by_name['NamespaceInfo']
_TABLEVIEW = DESCRIPTOR.message_types_by_name['TableView']
_TABLEVIEWROW = DESCRIPTOR.message_types_by_name['TableViewRow']
_NAMESPACEINFO_NAMESPACETYPE = _NAMESPACEINFO.enum_types_by_name['NamespaceType']
DatasetProfile = _reflection.GeneratedProtocolMessageType('DatasetProfile', (_message.Message,), {
  'DESCRIPTOR' : _DATASETPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.DatasetProfile)
  })
_sym_db.RegisterMessage(DatasetProfile)

ModelProfile = _reflection.GeneratedProtocolMessageType('ModelProfile', (_message.Message,), {

  'ImportanceEntry' : _reflection.GeneratedProtocolMessageType('ImportanceEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELPROFILE_IMPORTANCEENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.ModelProfile.ImportanceEntry)
    })
  ,
  'DESCRIPTOR' : _MODELPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.ModelProfile)
  })
_sym_db.RegisterMessage(ModelProfile)
_sym_db.RegisterMessage(ModelProfile.ImportanceEntry)

ROCCurve = _reflection.GeneratedProtocolMessageType('ROCCurve', (_message.Message,), {
  'DESCRIPTOR' : _ROCCURVE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.ROCCurve)
  })
_sym_db.RegisterMessage(ROCCurve)

PrecisionRecallCurve = _reflection.GeneratedProtocolMessageType('PrecisionRecallCurve', (_message.Message,), {
  'DESCRIPTOR' : _PRECISIONRECALLCURVE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.PrecisionRecallCurve)
  })
_sym_db.RegisterMessage(PrecisionRecallCurve)

ForecastProfile = _reflection.GeneratedProtocolMessageType('ForecastProfile', (_message.Message,), {
  'DESCRIPTOR' : _FORECASTPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.ForecastProfile)
  })
_sym_db.RegisterMessage(ForecastProfile)

StudyProfile = _reflection.GeneratedProtocolMessageType('StudyProfile', (_message.Message,), {
  'DESCRIPTOR' : _STUDYPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.StudyProfile)
  })
_sym_db.RegisterMessage(StudyProfile)

Plot = _reflection.GeneratedProtocolMessageType('Plot', (_message.Message,), {
  'DESCRIPTOR' : _PLOT,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.Plot)
  })
_sym_db.RegisterMessage(Plot)

ColumnProfile = _reflection.GeneratedProtocolMessageType('ColumnProfile', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.ColumnProfile)
  })
_sym_db.RegisterMessage(ColumnProfile)

Histogram = _reflection.GeneratedProtocolMessageType('Histogram', (_message.Message,), {
  'DESCRIPTOR' : _HISTOGRAM,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.Histogram)
  })
_sym_db.RegisterMessage(Histogram)

NamespaceInfo = _reflection.GeneratedProtocolMessageType('NamespaceInfo', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACEINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo)
  })
_sym_db.RegisterMessage(NamespaceInfo)

TableView = _reflection.GeneratedProtocolMessageType('TableView', (_message.Message,), {
  'DESCRIPTOR' : _TABLEVIEW,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.TableView)
  })
_sym_db.RegisterMessage(TableView)

TableViewRow = _reflection.GeneratedProtocolMessageType('TableViewRow', (_message.Message,), {
  'DESCRIPTOR' : _TABLEVIEWROW,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.TableViewRow)
  })
_sym_db.RegisterMessage(TableViewRow)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/common/v1'
  _MODELPROFILE_IMPORTANCEENTRY._options = None
  _MODELPROFILE_IMPORTANCEENTRY._serialized_options = b'8\001'
  _DATASETPROFILE._serialized_start=116
  _DATASETPROFILE._serialized_end=460
  _MODELPROFILE._serialized_start=463
  _MODELPROFILE._serialized_end=1053
  _MODELPROFILE_IMPORTANCEENTRY._serialized_start=1004
  _MODELPROFILE_IMPORTANCEENTRY._serialized_end=1053
  _ROCCURVE._serialized_start=1055
  _ROCCURVE._serialized_end=1147
  _PRECISIONRECALLCURVE._serialized_start=1149
  _PRECISIONRECALLCURVE._serialized_end=1262
  _FORECASTPROFILE._serialized_start=1264
  _FORECASTPROFILE._serialized_end=1366
  _STUDYPROFILE._serialized_start=1369
  _STUDYPROFILE._serialized_end=1601
  _PLOT._serialized_start=1603
  _PLOT._serialized_end=1679
  _COLUMNPROFILE._serialized_start=1682
  _COLUMNPROFILE._serialized_end=2661
  _HISTOGRAM._serialized_start=2663
  _HISTOGRAM._serialized_end=2724
  _NAMESPACEINFO._serialized_start=2727
  _NAMESPACEINFO._serialized_end=3101
  _NAMESPACEINFO_NAMESPACETYPE._serialized_start=2994
  _NAMESPACEINFO_NAMESPACETYPE._serialized_end=3101
  _TABLEVIEW._serialized_start=3104
  _TABLEVIEW._serialized_end=3290
  _TABLEVIEWROW._serialized_start=3292
  _TABLEVIEWROW._serialized_end=3322
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.cloudproxyd.v1 import cloudproxyd_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2


class CloudProxyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Download = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/Download',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileDownloadRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileDownloadResponse.FromString,
                )
        self.Upload = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/Upload',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileUploadRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileUploadResponse.FromString,
                )
        self.KeyExistInVirtualBucket = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/KeyExistInVirtualBucket',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.KeyExistInVirtualBucketRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.KeyExistInVirtualBucketResponse.FromString,
                )
        self.VirtualBucketExist = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/VirtualBucketExist',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.VirtualBucketExistRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.VirtualBucketExistResponse.FromString,
                )
        self.CreateVirtualBucketIfNotExist = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/CreateVirtualBucketIfNotExist',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.CreateVirtualBucketRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.CreateVirtualBucketResponse.FromString,
                )
        self.Shutdown = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/Shutdown',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.ShutdownRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.ShutdownResponse.FromString,
                )


class CloudProxyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Download(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Upload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KeyExistInVirtualBucket(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VirtualBucketExist(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateVirtualBucketIfNotExist(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Shutdown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CloudProxyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Download': grpc.unary_unary_rpc_method_handler(
                    servicer.Download,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileDownloadRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileDownloadResponse.SerializeToString,
            ),
            'Upload': grpc.unary_unary_rpc_method_handler(
                    servicer.Upload,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileUploadRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileUploadResponse.SerializeToString,
            ),
            'KeyExistInVirtualBucket': grpc.unary_unary_rpc_method_handler(
                    servicer.KeyExistInVirtualBucket,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.KeyExistInVirtualBucketRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.KeyExistInVirtualBucketResponse.SerializeToString,
            ),
            'VirtualBucketExist': grpc.unary_unary_rpc_method_handler(
                    servicer.VirtualBucketExist,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.VirtualBucketExistRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.VirtualBucketExistResponse.SerializeToString,
            ),
            'CreateVirtualBucketIfNotExist': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVirtualBucketIfNotExist,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.CreateVirtualBucketRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.CreateVirtualBucketResponse.SerializeToString,
            ),
            'Shutdown': grpc.unary_unary_rpc_method_handler(
                    servicer.Shutdown,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.ShutdownRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.ShutdownResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CloudProxyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/Download',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileDownloadRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileDownloadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Upload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/Upload',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileUploadRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.FileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KeyExistInVirtualBucket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/KeyExistInVirtualBucket',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.KeyExistInVirtualBucketRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.KeyExistInVirtualBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VirtualBucketExist(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/VirtualBucketExist',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.VirtualBucketExistRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.VirtualBucketExistResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateVirtualBucketIfNotExist(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/CreateVirtualBucketIfNotExist',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.CreateVirtualBucketRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.CreateVirtualBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Shutdown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService/Shutdown',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.ShutdownRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cloudproxyd_dot_v1_dot_cloudproxyd__pb2.ShutdownResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
